You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@openoffice.apache.org by pf...@apache.org on 2014/04/29 21:05:21 UTC

svn commit: r1591058 [12/15] - in /openoffice/trunk/main: ./ accessibility/bridge/org/openoffice/java/accessibility/ accessibility/bridge/source/java/ accessibility/inc/accessibility/extended/ accessibility/inc/accessibility/standard/ accessibility/sou...

Modified: openoffice/trunk/main/framework/qa/complex/loadAllDocuments/CheckXComponentLoader.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/qa/complex/loadAllDocuments/CheckXComponentLoader.java?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/qa/complex/loadAllDocuments/CheckXComponentLoader.java (original)
+++ openoffice/trunk/main/framework/qa/complex/loadAllDocuments/CheckXComponentLoader.java Tue Apr 29 19:05:05 2014
@@ -71,7 +71,7 @@ import static org.junit.Assert.*;
             The parameters for this have to be "ftp_access" and "http_access".
             If they are not given, tests for ftp and http will fail.
             
-    @todo   We need a further test for accessing UNC pathes on windows!            
+    @todo   We need a further test for accessing UNC paths on windows!            
  */
 public class CheckXComponentLoader
 {
@@ -185,7 +185,7 @@ public class CheckXComponentLoader
         // define default loader for testing
         // TODO think about using of bot loader instances!
         m_xLoader = UnoRuntime.queryInterface(XComponentLoader.class, m_xDesktop);
-        assertNotNull("Desktop service doesnt support needed component loader interface.", m_xLoader);
+        assertNotNull("Desktop service doesn't support needed component loader interface.", m_xLoader);
 
         // get temp path for this environment
         final String tempDirURL = util.utils.getOfficeTemp/*Dir*/(getMSF());
@@ -529,7 +529,7 @@ public class CheckXComponentLoader
 //        loadURL(m_xLoader, RESULT_ILLEGALARGUMENTEXCEPTION, sEmptyDocs, "_blank", 0,
 //                lProps);
 //
-//        System.out.println("check case senstive URLs");
+//        System.out.println("check case sensitive URLs");
 //
 //        sIllegalArgs = new String[] {
 //            "sLot:5000", "sloT:10909", ".unO:SaveAs", ".uno:OPEN",

Modified: openoffice/trunk/main/framework/qa/complex/loadAllDocuments/StatusIndicator.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/qa/complex/loadAllDocuments/StatusIndicator.java?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/qa/complex/loadAllDocuments/StatusIndicator.java (original)
+++ openoffice/trunk/main/framework/qa/complex/loadAllDocuments/StatusIndicator.java Tue Apr 29 19:05:05 2014
@@ -53,7 +53,7 @@ public class StatusIndicator implements 
 
     /**
      * @const SHOWSTATUS_NO         don't show the status - but save information about using of this indicator object
-     * @const SHOWSTATUS_LOG        the possible set protocol object will be used (it covers STDOUT, STDERR automaticly too)
+     * @const SHOWSTATUS_LOG        the possible set protocol object will be used (it covers STDOUT, STDERR automatically too)
      * @const SHOWSTATUS_DIALOG     the status will be shown inside a java dialog
      * @const SHOWSTATUS_LINK       the status will be notified to interested listener (one listener only!)
      */

Modified: openoffice/trunk/main/framework/qa/complex/loadAllDocuments/StreamSimulator.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/qa/complex/loadAllDocuments/StreamSimulator.java?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/qa/complex/loadAllDocuments/StreamSimulator.java (original)
+++ openoffice/trunk/main/framework/qa/complex/loadAllDocuments/StreamSimulator.java Tue Apr 29 19:05:05 2014
@@ -75,7 +75,7 @@ public class StreamSimulator implements 
      * @throw   com.sun.star.io.NotConnectedException
      *              in case the internal streams to the file on disk couldn't
      *              be established.
-     *              They are neccessary. Otherwhise this simulator can't
+     *              They are necessary. Otherwise this simulator can't
      *              really work.
      */
     public StreamSimulator(XMultiServiceFactory xMSF,
@@ -121,7 +121,7 @@ public class StreamSimulator implements 
     /**
      * following methods simulates the XInputStream.
      * The notice all actions inside the internal protocol
-     * and try to map all neccessary functions to the internal
+     * and try to map all necessary functions to the internal
      * open in-stream.
      */
     public int readBytes(byte[][] lData, int nBytesToRead )
@@ -275,7 +275,7 @@ public class StreamSimulator implements 
     /**
      * following methods simulates the XOutputStream.
      * The notice all actions inside the internal protocol
-     * and try to map all neccessary functions to the internal
+     * and try to map all necessary functions to the internal
      * open out-stream.
      */
     public void writeBytes(byte[] lData) 
@@ -369,7 +369,7 @@ public class StreamSimulator implements 
     /**
      * following methods simulates the XSeekable.
      * The notice all actions inside the internal protocol
-     * and try to map all neccessary functions to the internal
+     * and try to map all necessary functions to the internal
      * open stream.
      */
     public void seek(long nLocation ) 

Modified: openoffice/trunk/main/framework/qa/complex/path_settings/PathSettingsTest.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/qa/complex/path_settings/PathSettingsTest.java?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/qa/complex/path_settings/PathSettingsTest.java (original)
+++ openoffice/trunk/main/framework/qa/complex/path_settings/PathSettingsTest.java Tue Apr 29 19:05:05 2014
@@ -198,7 +198,7 @@ public class PathSettingsTest
     }
 
     /**
-     * Simple existance test, if this fails, the Lists must update
+     * Simple existence test, if this fails, the Lists must update
      */
     @Test
     public void checkInternalListConsistence()
@@ -909,7 +909,7 @@ public class PathSettingsTest
      */
     private String changeToCorrectValue(String path)
     {
-        // the simplest possiblity
+        // the simplest possibility
         if (path == null || path.equals(""))
         {
             String sTempDir = System.getProperty("java.io.tmpdir");

Modified: openoffice/trunk/main/framework/source/accelerators/acceleratorcache.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/source/accelerators/acceleratorcache.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/source/accelerators/acceleratorcache.cxx (original)
+++ openoffice/trunk/main/framework/source/accelerators/acceleratorcache.cxx Tue Apr 29 19:05:05 2014
@@ -69,7 +69,7 @@ AcceleratorCache::AcceleratorCache(const
 //-----------------------------------------------    
 AcceleratorCache::~AcceleratorCache()
 {
-    // Dont save anything automaticly here.
+    // Dont save anything automatically here.
     // The user has to do that explicitly!
 }
 

Modified: openoffice/trunk/main/framework/source/accelerators/acceleratorconfiguration.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/source/accelerators/acceleratorconfiguration.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/source/accelerators/acceleratorconfiguration.cxx (original)
+++ openoffice/trunk/main/framework/source/accelerators/acceleratorconfiguration.cxx Tue Apr 29 19:05:05 2014
@@ -587,7 +587,7 @@ void XMLBasedAcceleratorConfiguration::i
     css::uno::Reference< css::io::XTruncate > xClearable(xStream, css::uno::UNO_QUERY_THROW);
     xClearable->truncate();
     
-    // TODO can be removed if seek(0) is done by truncate() automaticly!
+    // TODO can be removed if seek(0) is done by truncate() automatically!
     css::uno::Reference< css::io::XSeekable > xSeek(xStream, css::uno::UNO_QUERY);
     if (xSeek.is())
         xSeek->seek(0);
@@ -637,7 +637,7 @@ AcceleratorCache& XMLBasedAcceleratorCon
     }
     
     // in case, we have a writeable cache, we use it for reading too!
-    // Otherwhise the API user cant find its own changes ...
+    // Otherwise the API user can't find its own changes ...
     if (m_pWriteCache)
         return *m_pWriteCache;
     else
@@ -1255,7 +1255,7 @@ void SAL_CALL XCUBasedAcceleratorConfigu
 
         // Only path of form "PrimaryKeys/Modules/Module['<module_name>']/Key['<command_url>']/Command[<locale>]" will
         // be interesting for use. Sometimes short path values are given also by the broadcaster ... but they must be ignored :-)
-        // So we try to split the path into 3 parts (module isnt important here, because we already know it ... because
+        // So we try to split the path into 3 parts (module isn't important here, because we already know it ... because
         // these instance is bound to a specific module configuration ... or it''s the global configuration where no module is given at all.
     
         ::rtl::OUString sOrgPath ;
@@ -1680,7 +1680,7 @@ AcceleratorCache& XCUBasedAcceleratorCon
         }
 
         // in case, we have a writeable cache, we use it for reading too!
-        // Otherwhise the API user cant find its own changes ...
+        // Otherwise the API user can't find its own changes ...
         if (m_pPrimaryWriteCache)
             return *m_pPrimaryWriteCache;
         else
@@ -1700,7 +1700,7 @@ AcceleratorCache& XCUBasedAcceleratorCon
         }
 
         // in case, we have a writeable cache, we use it for reading too!
-        // Otherwhise the API user cant find its own changes ...
+        // Otherwise the API user can't find its own changes ...
         if (m_pSecondaryWriteCache)
             return *m_pSecondaryWriteCache;
         else

Modified: openoffice/trunk/main/framework/source/accelerators/acceleratorexecute.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/source/accelerators/acceleratorexecute.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/source/accelerators/acceleratorexecute.cxx (original)
+++ openoffice/trunk/main/framework/source/accelerators/acceleratorexecute.cxx Tue Apr 29 19:05:05 2014
@@ -174,7 +174,7 @@ void AcceleratorExecute::execute(const c
 {
     ::rtl::OUString sCommand = impl_ts_findCommand(aAWTKey);
 
-    // No Command found? Do nothing! User isnt interested on any error handling .-)
+    // No Command found? Do nothing! User isn't interested on any error handling .-)
     if (!sCommand.getLength())
         return;
     

Modified: openoffice/trunk/main/framework/source/accelerators/acceleratorexecute.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/source/accelerators/acceleratorexecute.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/source/accelerators/acceleratorexecute.hxx (original)
+++ openoffice/trunk/main/framework/source/accelerators/acceleratorexecute.hxx Tue Apr 29 19:05:05 2014
@@ -93,7 +93,7 @@ struct TMutexInit
             Because exceution of an accelerator command can be dangerous
             (in case it force an office shutdown for key "ALT+F4"!)
             all internal dispatches are done asynchronous.
-            Menas that the trigger call doesnt wait till the dispatch
+            Menas that the trigger call doesn't wait till the dispatch
             is finished. You can call very often. All requests will be
             queued internal and dispatched ASAP.
 

Modified: openoffice/trunk/main/framework/source/accelerators/keymapping.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/source/accelerators/keymapping.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/source/accelerators/keymapping.cxx (original)
+++ openoffice/trunk/main/framework/source/accelerators/keymapping.cxx Tue Apr 29 19:05:05 2014
@@ -187,7 +187,7 @@ sal_uInt16 KeyMapping::mapIdentifierToCo
     sal_uInt16 nCode = 0;
     if (!KeyMapping::impl_st_interpretIdentifierAsPureKeyCode(sIdentifier, nCode))
         throw css::lang::IllegalArgumentException(
-                DECLARE_ASCII("Cant map given identifier to a valid key code value."),
+                DECLARE_ASCII("Can't map given identifier to a valid key code value."),
                 css::uno::Reference< css::uno::XInterface >(),
                 0);
                 

Modified: openoffice/trunk/main/framework/source/accelerators/presethandler.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/source/accelerators/presethandler.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/source/accelerators/presethandler.cxx (original)
+++ openoffice/trunk/main/framework/source/accelerators/presethandler.cxx Tue Apr 29 19:05:05 2014
@@ -277,7 +277,7 @@ css::uno::Reference< css::embed::XStorag
     /*
     // TODO remove me!
     // Attention: This is temp. workaround ... We create a temp. storage file
-    // based of a sytem directory. This must be used so, till the storage implementation
+    // based of a system directory. This must be used so, till the storage implementation
     // can work on directories too.
     */
     css::uno::Sequence< css::uno::Any > lArgs(2);
@@ -445,7 +445,7 @@ void PresetHandler::connectToResource(  
 
     // a) inside share layer we should not create any new structures ... We jave to use
     //    existing ones only!
-    // b) inside user layer we can (SOFT mode!) but sometimes we shouldnt (HARD mode!)
+    // b) inside user layer we can (SOFT mode!) but sometimes we shouldn't (HARD mode!)
     //    create new empty structures. We should preferr using of any existing structure.
     sal_Int32 eShareMode = (css::embed::ElementModes::READ      | css::embed::ElementModes::NOCREATE); 
     sal_Int32 eUserMode  = (css::embed::ElementModes::READWRITE                                     );
@@ -879,7 +879,7 @@ css::uno::Reference< css::embed::XStorag
        )
         return css::uno::Reference< css::embed::XStorage >(); 
     
-    // it doesnt matter, if there is a locale fallback or not
+    // it doesn't matter, if there is a locale fallback or not
     // If creation of storages is allowed, we do it anyway.
     // Otherwhise we have no acc config at all, which can make other trouble.
     ::rtl::OUString sLocalizedPath;

Modified: openoffice/trunk/main/framework/source/accelerators/storageholder.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/source/accelerators/storageholder.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/source/accelerators/storageholder.cxx (original)
+++ openoffice/trunk/main/framework/source/accelerators/storageholder.cxx Tue Apr 29 19:05:05 2014
@@ -201,7 +201,7 @@ css::uno::Reference< css::embed::XStorag
                     /* TODO URGENT!
                         in case we found some "already existing storages" on the path before and increased its UseCount ...
                         and now we will get an exception on creating a new sub storage ...
-                        we must decrease all UseCounts, which was touched before. Otherwise these storages cant be closed!
+                        we must decrease all UseCounts, which was touched before. Otherwise these storages can't be closed!
 
                         Idea: Using of another structure member "PossibleUseCount" as vector of unique numbers.
                         Every thread use another unique number to identify all "owned candidates".
@@ -257,7 +257,7 @@ StorageHolder::TStorageList StorageHolde
         if (pCheck == m_lStorages.end())
         {
             // at least one path element was not found
-            // Seems that this path isnt open ...
+            // Seems that this path isn't open ...
             lStoragesOfPath.clear();
             return lStoragesOfPath;
         }
@@ -308,7 +308,7 @@ void StorageHolder::closePath(const ::rt
     ::rtl::OUString sNormedPath = StorageHolder::impl_st_normPath(rPath);
     OUStringList    lFolders    = StorageHolder::impl_st_parsePath(sNormedPath);
     
-    /* convert list of pathes in the following way:
+    /* convert list of paths in the following way:
         [0] = "path_1" => "path_1
         [1] = "path_2" => "path_1/path_2"
         [2] = "path_3" => "path_1/path_2/path_3"

Modified: openoffice/trunk/main/framework/source/application/framework.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/source/application/framework.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/source/application/framework.cxx (original)
+++ openoffice/trunk/main/framework/source/application/framework.cxx Tue Apr 29 19:05:05 2014
@@ -175,7 +175,7 @@ void FrameWork::impl_analyzeCommandArgum
 	sal_uInt32		nCount		= aInfo.getCommandArgCount();
 	for ( sal_uInt32 nArgument=0; nArgument<nCount; ++nArgument )
 	{
-		// If extraction of current argument successfull ...
+		// If extraction of current argument successful ...
 		if ( aInfo.getCommandArg( nArgument, sArgument ) == osl_Process_E_None )
 		{
 			// ... search for matching with supported values.

Modified: openoffice/trunk/main/framework/source/application/login.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/source/application/login.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/source/classes/menumanager.cxx (original)
+++ openoffice/trunk/main/framework/source/classes/menumanager.cxx Tue Apr 29 19:05:05 2014
@@ -907,7 +907,7 @@ IMPL_LINK( MenuManager, Activate, Menu *
 		::rtl::OUString aCommand( m_aMenuItemCommand );
 		if ( m_aMenuItemCommand.matchIgnoreAsciiCase( UNO_COMMAND, 0 ))
 		{
-			// Remove protocol part from command so we can use an easier comparision method
+			// Remove protocol part from command so we can use an easier comparison method
 			aCommand = aCommand.copy( UNO_COMMAND.getLength() );
 		}
 

Modified: openoffice/trunk/main/framework/source/classes/taskcreator.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/source/classes/taskcreator.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/source/classes/taskcreator.cxx (original)
+++ openoffice/trunk/main/framework/source/classes/taskcreator.cxx Tue Apr 29 19:05:05 2014
@@ -68,7 +68,7 @@ namespace framework{
 //_________________________________________________________________________________________________________________
 
 /*-****************************************************************************************************//**
-    @short      initialize instance with neccessary informations
+    @short      initialize instance with necessary informations
     @descr      We need a valid uno service manager to create or instanciate new services.
                 All other informations to create frames or tasks come in on right interface methods.
 
@@ -129,7 +129,7 @@ css::uno::Reference< css::frame::XFrame 
     catch(const css::uno::Exception&)
     {}
 
-    // no catch here ... without an task creator service we cant open ANY document window within the office.
+    // no catch here ... without an task creator service we can't open ANY document window within the office.
     // Thats IMHO not a good idea. Then we should accept the stacktrace showing us the real problem.
     // BTW: The used fallback creator service (IMPLEMENTATIONNAME_FWK_TASKCREATOR) is implemented in the same
     // library then these class here ... Why we should not be able to create it ?

Modified: openoffice/trunk/main/framework/source/dispatch/closedispatcher.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/source/dispatch/closedispatcher.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/source/dispatch/closedispatcher.cxx (original)
+++ openoffice/trunk/main/framework/source/dispatch/closedispatcher.cxx Tue Apr 29 19:05:05 2014
@@ -129,7 +129,7 @@ css::uno::Sequence< css::frame::Dispatch
 {
     if (nCommandGroup == css::frame::CommandGroup::VIEW)
     {
-        /* Attention: Dont add .uno:CloseFrame here. Because its not realy
+        /* Attention: Dont add .uno:CloseFrame here. Because its not really
                       a configurable feature ... and further it does not have
                       a valid UIName entry inside the GenericCommands.xcu ... */
         css::uno::Sequence< css::frame::DispatchInformation > lViewInfos(1);
@@ -215,13 +215,13 @@ void SAL_CALL CloseDispatcher::dispatchW
     }
 
     // OK - URLs are the right ones.
-    // But we cant execute synchronously :-)
+    // But we can't execute synchronously :-)
     // May we are called from a generic key-input handler,
-    // which isnt aware that this call kill its own environment ...
+    // which isn't aware that this call kill its own environment ...
     // Do it asynchronous everytimes!
 
     // But dont forget to hold usself alive.
-    // We are called back from an environment, which doesnt know an uno reference.
+    // We are called back from an environment, which doesn't know an uno reference.
     // They call us back by using our c++ interface.
 
     m_xResultListener = xListener;
@@ -254,7 +254,7 @@ void SAL_CALL CloseDispatcher::dispatchW
                 Now we do the following:
                 - close all views to the same document, if needed and possible
                 - make the current frame empty
-                  ! This step is neccessary to handle errors during closing the
+                  ! This step is necessary to handle errors during closing the
                     document inside the frame. May the document shows a dialog and
                     the user ignore it. Then the state of the office can be changed
                     during we try to close frame and document.
@@ -306,7 +306,7 @@ IMPL_LINK( CloseDispatcher, impl_asyncCa
     FrameListAnalyzer aCheck1(xDesktop, xCloseFrame, FrameListAnalyzer::E_HELP | FrameListAnalyzer::E_BACKINGCOMPONENT);
 
     // a) If the curent frame (where the close dispatch was requested for) does not have
-    //    any parent frame ... it will close this frame only. Such frame isnt part of the
+    //    any parent frame ... it will close this frame only. Such frame isn't part of the
     //    global desktop tree ... and such frames are used as "implementation details" only.
     //    E.g. the live previews of our wizards doing such things. And then the owner of the frame
     //    is responsible for closing the application or accepting closing of the application
@@ -315,9 +315,9 @@ IMPL_LINK( CloseDispatcher, impl_asyncCa
         bCloseFrame = sal_True;
     else
 
-    // b) The help window cant disagree with any request.
-    //    Because it doesnt implement a controller - it uses a window only.
-    //    Further t cant be the last open frame - if we do all other things
+    // b) The help window can't disagree with any request.
+    //    Because it doesn't implement a controller - it uses a window only.
+    //    Further t can't be the last open frame - if we do all other things
     //    right inside this CloseDispatcher implementation.
     //    => close it!
     if (aCheck1.m_bReferenceIsHelp)
@@ -326,7 +326,7 @@ IMPL_LINK( CloseDispatcher, impl_asyncCa
 
     // c) If we are already in "backing mode", we have to terminate
     //    the application, if this special frame is closed.
-    //    It doesnt matter, how many other frames (can be the help or hidden frames only)
+    //    It doesn't matter, how many other frames (can be the help or hidden frames only)
     //    are open then.
     //    => terminate the application!
     if (aCheck1.m_bReferenceIsBacking)
@@ -436,7 +436,7 @@ IMPL_LINK( CloseDispatcher, impl_asyncCa
     // We reached this method only, by using a reference to ourself :-)
     // Further this member is used to detect still running and not yet finished
     // ansynchronous operations. So its time now to release this reference.
-    // But hold it temp alive. Otherwhise we die before we can finish this method realy :-))
+    // But hold it temp alive. Otherwise we die before we can finish this method really :-))
     css::uno::Reference< css::uno::XInterface > xTempHold = m_xSelfHold;
     m_xSelfHold.clear();
     m_xResultListener.clear();
@@ -500,9 +500,9 @@ sal_Bool CloseDispatcher::implts_prepare
         }
     }
 
-    // dont remove the component realy by e.g. calling setComponent(null, null).
+    // dont remove the component really by e.g. calling setComponent(null, null).
     // It's enough to suspend the controller.
-    // If we close the frame later this controller doesnt show the same dialog again.
+    // If we close the frame later this controller doesn't show the same dialog again.
     return sal_True;
 }
 
@@ -621,8 +621,8 @@ css::uno::Reference< css::frame::XFrame 
         if (xTopWindowCheck.is())
         {
             // b1) Note: Toolkit interface XTopWindow sometimes is used by real VCL-child-windows also .-)
-            //     Be sure that these window is realy a "top system window".
-            //     Attention ! Checking Window->GetParent() isnt the right approach here.
+            //     Be sure that these window is really a "top system window".
+            //     Attention ! Checking Window->GetParent() isn't the right approach here.
             //     Because sometimes VCL create "implicit border windows" as parents even we created
             //     a simple XWindow using the toolkit only .-(
             ::vos::OGuard aSolarLock(&Application::GetSolarMutex());

Modified: openoffice/trunk/main/framework/source/dispatch/dispatchinformationprovider.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/source/dispatch/dispatchinformationprovider.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/source/dispatch/dispatchinformationprovider.cxx (original)
+++ openoffice/trunk/main/framework/source/dispatch/dispatchinformationprovider.cxx Tue Apr 29 19:05:05 2014
@@ -85,7 +85,7 @@ css::uno::Sequence< sal_Int16 > SAL_CALL
     
     for (i1=0; i1<c1; ++i1)
     {
-        // ignore controller, which doesnt implement the right interface
+        // ignore controller, which doesn't implement the right interface
         css::uno::Reference< css::frame::XDispatchInformationProvider > xProvider = lProvider[i1];
         if (!xProvider.is())
             continue;
@@ -119,7 +119,7 @@ css::uno::Sequence< css::frame::Dispatch
     {
         try
         {
-            // ignore controller, which doesnt implement the right interface
+            // ignore controller, which doesn't implement the right interface
             css::uno::Reference< css::frame::XDispatchInformationProvider > xProvider = lProvider[i1];
             if (!xProvider.is())
                 continue;

Modified: openoffice/trunk/main/framework/source/dispatch/dispatchprovider.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/source/dispatch/dispatchprovider.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/source/dispatch/helpagentdispatcher.cxx (original)
+++ openoffice/trunk/main/framework/source/dispatch/helpagentdispatcher.cxx Tue Apr 29 19:05:05 2014
@@ -217,7 +217,7 @@ void HelpAgentDispatcher::implts_acceptC
 	aWriteLock.unlock();
 	// <- SAFE
 	
-	// We must make sure that this URL isnt marked as ignored by the user.
+	// We must make sure that this URL isn't marked as ignored by the user.
 	// Otherwhise the user wont see the corresponding help content in the future.
 	SvtHelpOptions().resetAgentIgnoreURLCounter(sAcceptedURL);
 
@@ -285,7 +285,7 @@ void HelpAgentDispatcher::implts_startTi
 	// SAFE ->
 	// Timer uses pointer to this help agent dispatcher ...
 	// But normaly we are ref counted. So we must make sure that this
-	// dispatcher isnt killed during the timer runs .-)
+	// dispatcher isn't killed during the timer runs .-)
 	WriteGuard aWriteLock(m_aLock);
 	m_xSelfHold = css::uno::Reference< css::uno::XInterface >(static_cast< css::frame::XDispatch* >(this), css::uno::UNO_QUERY_THROW);
 	aWriteLock.unlock();

Modified: openoffice/trunk/main/framework/source/dispatch/interceptionhelper.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/source/dispatch/interceptionhelper.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/source/dispatch/interceptionhelper.cxx (original)
+++ openoffice/trunk/main/framework/source/dispatch/interceptionhelper.cxx Tue Apr 29 19:05:05 2014
@@ -97,7 +97,7 @@ css::uno::Reference< css::frame::XDispat
     ReadGuard aReadLock(m_aLock);
 
     // a) first search an interceptor, which match to this URL by it's URL pattern registration
-    //    Note: if it return NULL - it does not mean an empty interceptor list automaticly!
+    //    Note: if it return NULL - it does not mean an empty interceptor list automatically!
     css::uno::Reference< css::frame::XDispatchProvider > xInterceptor;
     InterceptorList::const_iterator pIt = m_lInterceptionRegs.findByPattern(aURL.Complete);
     if (pIt != m_lInterceptionRegs.end())
@@ -107,7 +107,7 @@ css::uno::Reference< css::frame::XDispat
     //    Use first interceptor everytimes.
     //    Note: it doesn't matter, which direction this helper implementation use to ask interceptor objects.
     //    Using of member m_aInterceptorList will starts at the beginning everytimes.
-    //    It depends from the filling operation, in which direction it works realy!
+    //    It depends from the filling operation, in which direction it works really!
     if (!xInterceptor.is() && m_lInterceptionRegs.size()>0)
     {
         pIt          = m_lInterceptionRegs.begin();
@@ -300,7 +300,7 @@ void SAL_CALL InterceptionHelper::dispos
     css::uno::Reference< css::frame::XDispatchProvider > xThis(static_cast< ::cppu::OWeakObject* >(this), css::uno::UNO_QUERY_THROW);
 
     // We need a full copy of all currently registered interceptor objects.
-    // Otherwhise we cant iterate over this vector without the risk, that our iterator will be invalid.
+    // Otherwise we can't iterate over this vector without the risk, that our iterator will be invalid.
     // Because this vetor will be influenced by every deregistered interceptor.
     InterceptionHelper::InterceptorList aCopy = m_lInterceptionRegs;
 

Modified: openoffice/trunk/main/framework/source/dispatch/loaddispatcher.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/source/dispatch/loaddispatcher.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/source/dispatch/loaddispatcher.cxx (original)
+++ openoffice/trunk/main/framework/source/dispatch/loaddispatcher.cxx Tue Apr 29 19:05:05 2014
@@ -128,7 +128,7 @@ css::uno::Any LoadDispatcher::impl_dispa
                                              const css::uno::Reference< css::frame::XDispatchResultListener >& xListener )
 {
     // Attention: May be nobody outside hold such temp. dispatch object alive (because
-    // the container in which we resists isnt implemented threadsafe but updated by a timer
+    // the container in which we resists isn't implemented threadsafe but updated by a timer
     // and clear our reference ...) we should hold us self alive!
     css::uno::Reference< css::uno::XInterface > xThis(static_cast< css::frame::XNotifyingDispatch* >(this), css::uno::UNO_QUERY);
 
@@ -144,7 +144,7 @@ css::uno::Any LoadDispatcher::impl_dispa
     {
         if (xListener.is())
             xListener->dispatchFinished(
-                css::frame::DispatchResultEvent(xThis, css::frame::DispatchResultState::DONTKNOW, css::uno::Any())); // DONTKNOW? ... not realy started ... not realy failed :-)
+                css::frame::DispatchResultEvent(xThis, css::frame::DispatchResultState::DONTKNOW, css::uno::Any())); // DONTKNOW? ... not really started ... not really failed :-)
     }
 
     css::uno::Reference< css::frame::XFrame > xBaseFrame(m_xOwnerFrame.get(), css::uno::UNO_QUERY);

Modified: openoffice/trunk/main/framework/source/dispatch/mailtodispatcher.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/source/dispatch/mailtodispatcher.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/source/dispatch/mailtodispatcher.cxx (original)
+++ openoffice/trunk/main/framework/source/dispatch/mailtodispatcher.cxx Tue Apr 29 19:05:05 2014
@@ -103,7 +103,7 @@ DEFINE_INIT_SERVICE(MailToDispatcher,
 
 /**
     @short      standard ctor
-    @descr      These initialize a new instance of ths class with needed informations for work.
+    @descr      These initialize a new instance of this class with needed informations for work.
 
     @param      xContext
                     reference to uno component context
@@ -140,7 +140,7 @@ MailToDispatcher::~MailToDispatcher()
                 be asked by the generic dispatch mechanism inside framework, if he can handle this
                 special URL wich match his registration. He can agree by returning of a valid dispatch
                 instance or disagree by returning <NULL/>.
-                We don't create new dispatch instances here realy - we return THIS as result to handle it
+                We don't create new dispatch instances here really - we return THIS as result to handle it
                 at the same implementation.
 
     @modified   02.05.2002 15:25, as96863
@@ -195,7 +195,7 @@ css::uno::Sequence< css::uno::Reference<
 void SAL_CALL MailToDispatcher::dispatch( const css::util::URL&                                  aURL       ,
                                           const css::uno::Sequence< css::beans::PropertyValue >& lArguments ) throw( css::uno::RuntimeException )
 {
-    // dispatch() is an [oneway] call ... and may our user release his reference to us immediatly.
+    // dispatch() is an [oneway] call ... and may our user release his reference to us immediately.
     // So we should hold us self alive till this call ends.
     css::uno::Reference< css::frame::XNotifyingDispatch > xSelfHold(static_cast< ::cppu::OWeakObject* >(this), css::uno::UNO_QUERY);
     implts_dispatch(aURL,lArguments);
@@ -222,7 +222,7 @@ void SAL_CALL MailToDispatcher::dispatch
                                                           const css::uno::Sequence< css::beans::PropertyValue >&            lArguments,
                                                           const css::uno::Reference< css::frame::XDispatchResultListener >& xListener ) throw( css::uno::RuntimeException )
 {
-    // This class was designed to die by reference. And if user release his reference to us immediatly after calling this method
+    // This class was designed to die by reference. And if user release his reference to us immediately after calling this method
     // we can run into some problems. So we hold us self alive till this method ends.
     // Another reason: We can use this reference as source of sending event at the end too.
     css::uno::Reference< css::frame::XNotifyingDispatch > xThis(static_cast< ::cppu::OWeakObject* >(this), css::uno::UNO_QUERY);
@@ -256,8 +256,8 @@ void SAL_CALL MailToDispatcher::dispatch
 
     @return     <TRUE/> if dispatch could be started successfully
                 Note: Our internal used shell executor doesn't return any state value - so we must
-                belive that call was successfully.
-                <FALSE/> if neccessary ressource couldn't be created or an exception was thrown.
+                believe that call was successfully.
+                <FALSE/> if necessary ressource couldn't be created or an exception was thrown.
 
     @modified   30.04.2002 14:49, as96863
 */
@@ -306,7 +306,7 @@ sal_Bool MailToDispatcher::implts_dispat
     @param      xListener
                     reference to a valid listener for state events
     @param      aURL
-                    URL about listener will be informed, if something occured
+                    URL about listener will be informed, if something occurred
 
     @modified   30.04.2002 14:49, as96863
 */

Modified: openoffice/trunk/main/framework/source/dispatch/menudispatcher.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/source/dispatch/menudispatcher.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/source/dispatch/menudispatcher.cxx (original)
+++ openoffice/trunk/main/framework/source/dispatch/menudispatcher.cxx Tue Apr 29 19:05:05 2014
@@ -411,7 +411,7 @@ IMPL_LINK( MenuDispatcher, Close_Impl, v
 
 	ATTENTION
 
-		If you miss a test for one of this parameters, contact the autor or add it himself !(?)
+		If you miss a test for one of this parameters, contact the author or add it himself !(?)
 		But ... look for right testing! See using of this methods!
 -----------------------------------------------------------------------------------------------------------------*/
 

Modified: openoffice/trunk/main/framework/source/dispatch/oxt_handler.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/source/dispatch/oxt_handler.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/source/dispatch/servicehandler.cxx (original)
+++ openoffice/trunk/main/framework/source/dispatch/servicehandler.cxx Tue Apr 29 19:05:05 2014
@@ -102,7 +102,7 @@ DEFINE_INIT_SERVICE(ServiceHandler,
 
 /**
     @short      standard ctor
-    @descr      These initialize a new instance of ths class with needed informations for work.
+    @descr      These initialize a new instance of this class with needed informations for work.
 
     @param      xFactory
                 reference to uno servicemanager for creation of new services
@@ -139,7 +139,7 @@ ServiceHandler::~ServiceHandler()
                 be asked by the generic dispatch mechanism inside framework, if he can handle this
                 special URL wich match his registration. He can agree by returning of a valid dispatch
                 instance or disagree by returning <NULL/>.
-                We don't create new dispatch instances here realy - we return THIS as result to handle it
+                We don't create new dispatch instances here really - we return THIS as result to handle it
                 at the same implementation.
 
     @modified   02.05.2002 15:25, as96863
@@ -193,7 +193,7 @@ css::uno::Sequence< css::uno::Reference<
 void SAL_CALL ServiceHandler::dispatch( const css::util::URL&                                  aURL       ,
                                     const css::uno::Sequence< css::beans::PropertyValue >& lArguments ) throw( css::uno::RuntimeException )
 {
-    // dispatch() is an [oneway] call ... and may our user release his reference to us immediatly.
+    // dispatch() is an [oneway] call ... and may our user release his reference to us immediately.
     // So we should hold us self alive till this call ends.
     css::uno::Reference< css::frame::XNotifyingDispatch > xSelfHold(static_cast< ::cppu::OWeakObject* >(this), css::uno::UNO_QUERY);
     implts_dispatch(aURL,lArguments);
@@ -220,7 +220,7 @@ void SAL_CALL ServiceHandler::dispatchWi
                                                         const css::uno::Sequence< css::beans::PropertyValue >&            lArguments,
                                                         const css::uno::Reference< css::frame::XDispatchResultListener >& xListener ) throw( css::uno::RuntimeException )
 {
-    // This class was designed to die by reference. And if user release his reference to us immediatly after calling this method
+    // This class was designed to die by reference. And if user release his reference to us immediately after calling this method
     // we can run into some problems. So we hold us self alive till this method ends.
     // Another reason: We can use this reference as source of sending event at the end too.
     css::uno::Reference< css::frame::XNotifyingDispatch > xThis(static_cast< ::cppu::OWeakObject* >(this), css::uno::UNO_QUERY);
@@ -292,7 +292,7 @@ css::uno::Reference< css::uno::XInterfac
     if (!sServiceName.getLength())
         return css::uno::Reference< css::uno::XInterface >();
     
-    // If a service doesnt support an optional job executor interface - he can't get
+    // If a service doesn't support an optional job executor interface - he can't get
     // any given parameters!
     // Because we can't know if we must call createInstanceWithArguments() or XJobExecutor::trigger() ...
 
@@ -326,7 +326,7 @@ css::uno::Reference< css::uno::XInterfac
     @param      xListener
                     reference to a valid listener for state events
     @param      aURL
-                    URL about listener will be informed, if something occured
+                    URL about listener will be informed, if something occurred
 
     @modified   30.04.2002 14:49, as96863
 */

Modified: openoffice/trunk/main/framework/source/fwe/classes/actiontriggerpropertyset.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/source/fwe/classes/actiontriggerpropertyset.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/source/fwe/classes/actiontriggerpropertyset.cxx (original)
+++ openoffice/trunk/main/framework/source/fwe/classes/actiontriggerpropertyset.cxx Tue Apr 29 19:05:05 2014
@@ -310,7 +310,7 @@ void SAL_CALL ActionTriggerPropertySet::
 		if( pInfoHelper == NULL )
 		{
 			// Define static member to give structure of properties to baseclass "OPropertySetHelper".
-			// "impl_getStaticPropertyDescriptor" is a non exported and static funtion, who will define a static propertytable.
+			// "impl_getStaticPropertyDescriptor" is a non exported and static function, who will define a static propertytable.
 			// "sal_True" say: Table is sorted by name.
 			static OPropertyArrayHelper aInfoHelper( impl_getStaticPropertyDescriptor(), sal_True );
 			pInfoHelper = &aInfoHelper;

Modified: openoffice/trunk/main/framework/source/fwe/classes/actiontriggerseparatorpropertyset.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/source/fwe/classes/actiontriggerseparatorpropertyset.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/source/fwe/classes/actiontriggerseparatorpropertyset.cxx (original)
+++ openoffice/trunk/main/framework/source/fwe/classes/actiontriggerseparatorpropertyset.cxx Tue Apr 29 19:05:05 2014
@@ -254,7 +254,7 @@ void SAL_CALL ActionTriggerSeparatorProp
 		if( pInfoHelper == NULL )
 		{
 			// Define static member to give structure of properties to baseclass "OPropertySetHelper".
-			// "impl_getStaticPropertyDescriptor" is a non exported and static funtion, who will define a static propertytable.
+			// "impl_getStaticPropertyDescriptor" is a non exported and static function, who will define a static propertytable.
 			// "sal_True" say: Table is sorted by name.
 			static OPropertyArrayHelper aInfoHelper( impl_getStaticPropertyDescriptor(), sal_True );
 			pInfoHelper = &aInfoHelper;

Modified: openoffice/trunk/main/framework/source/fwe/classes/framelistanalyzer.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/source/fwe/classes/framelistanalyzer.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/source/fwe/classes/framelistanalyzer.cxx (original)
+++ openoffice/trunk/main/framework/source/fwe/classes/framelistanalyzer.cxx Tue Apr 29 19:05:05 2014
@@ -90,7 +90,7 @@ FrameListAnalyzer::~FrameListAnalyzer()
 
     We try to get a snapshot of all opened frames, which are part of the desktop frame container.
     Of course we can't access frames, which stands outside of this tree.
-    But it's neccessary to collect top frames here only. Otherwhise we interpret closing of last
+    But it's necessary to collect top frames here only. Otherwise we interpret closing of last
     frame wrong. Further we analyze this list and split into different parts.
     E.g. for "CloseDoc" we must know, which frames of the given list referr to the same model.
     These frames must be closed then. But all other frames must be untouched.
@@ -126,7 +126,7 @@ void FrameListAnalyzer::impl_analyze()
     // ask for the model of the given reference frame.
     // It must be compared with the model of every frame of the container
     // to sort it into the list of frames with the same model.
-    // Supress this step, if right detect mode isn't set.
+    // Suppress this step, if right detect mode isn't set.
     css::uno::Reference< css::frame::XModel > xReferenceModel;
     if ((m_eDetectMode & E_MODEL) == E_MODEL )
     {
@@ -138,7 +138,7 @@ void FrameListAnalyzer::impl_analyze()
     }
 
     // check, if the reference frame is in hidden mode.
-    // But look, if this analyze step is realy needed.
+    // But look, if this analyze step is really needed.
     css::uno::Reference< css::beans::XPropertySet > xSet(m_xReferenceFrame, css::uno::UNO_QUERY);
     if (
         ((m_eDetectMode & E_HIDDEN) == E_HIDDEN) &&
@@ -149,7 +149,7 @@ void FrameListAnalyzer::impl_analyze()
     }
 
     // check, if the reference frame includes the backing component.
-    // But look, if this analyze step is realy needed.
+    // But look, if this analyze step is really needed.
     if (((m_eDetectMode & E_BACKINGCOMPONENT) == E_BACKINGCOMPONENT) && m_xReferenceFrame.is() )
     {
         try
@@ -169,7 +169,7 @@ void FrameListAnalyzer::impl_analyze()
     }
 
     // check, if the reference frame includes the help module.
-    // But look, if this analyze step is realy needed.
+    // But look, if this analyze step is really needed.
     if (
         ((m_eDetectMode & E_HELP)     == E_HELP                ) &&
         (m_xReferenceFrame.is()                                ) &&
@@ -210,7 +210,7 @@ void FrameListAnalyzer::impl_analyze()
 
             // -------------------------------------------------
             // a) Is it the special help task?
-            //    Return it seperated from any return list.
+            //    Return it separated from any return list.
             if (
                 ((m_eDetectMode & E_HELP) == E_HELP      ) &&
                 (xFrame->getName()==SPECIALTARGET_HELPTASK)
@@ -222,7 +222,7 @@ void FrameListAnalyzer::impl_analyze()
 
             // -------------------------------------------------
             // b) Or is includes this task the special backing component?
-            //    Return it seperated from any return list.
+            //    Return it separated from any return list.
             //    But check if the reference task itself is the backing frame.
             //    Our user mst know it to decide right.
             if ((m_eDetectMode & E_BACKINGCOMPONENT) == E_BACKINGCOMPONENT)
@@ -289,8 +289,8 @@ void FrameListAnalyzer::impl_analyze()
     catch(css::lang::IndexOutOfBoundsException)
     {
         // stop copying if index seams to be wrong.
-        // This interface can't realy guarantee its count for multithreaded
-        // environments. So it can occure!
+        // This interface can't really guarantee its count for multithreaded
+        // environments. So it can occur!
     }
 
     // Pack both lists by using the actual step positions.

Modified: openoffice/trunk/main/framework/source/fwe/dispatch/interaction.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/source/fwe/dispatch/interaction.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/source/fwe/dispatch/interaction.cxx (original)
+++ openoffice/trunk/main/framework/source/fwe/dispatch/interaction.cxx Tue Apr 29 19:05:05 2014
@@ -45,7 +45,7 @@ namespace framework{
                     Why? Normaly interaction should show a filter selection dialog and ask user for his decision.
                     He can select any filter - then instances of these class will be called by handler ... or user
                     close dialog without any selection. Then another continuation should be slected by handler to
-                    abort continuations ... Retrying isn't very usefull here ... I think.
+                    abort continuations ... Retrying isn't very useful here ... I think.
 
     @implements     XInteractionFilterSelect
 
@@ -116,7 +116,7 @@ private:
 };
 
 //---------------------------------------------------------------------------------------------------------
-// initialize instance with all neccessary informations
+// initialize instance with all necessary informations
 // We use it without any further checks on our member then ...!
 //---------------------------------------------------------------------------------------------------------
 RequestFilterSelect_Impl::RequestFilterSelect_Impl( const ::rtl::OUString& sURL )
@@ -261,7 +261,7 @@ uno::Reference < task::XInteractionReque
 }
 
 //---------------------------------------------------------------------------------------------------------
-// initialize instance with all neccessary informations
+// initialize instance with all necessary informations
 // We use it without any further checks on our member then ...!
 //---------------------------------------------------------------------------------------------------------
 RequestAmbigousFilter_Impl::RequestAmbigousFilter_Impl( const ::rtl::OUString& sURL            ,

Modified: openoffice/trunk/main/framework/source/fwe/helper/titlehelper.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/source/fwe/helper/titlehelper.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/source/fwe/helper/titlehelper.cxx (original)
+++ openoffice/trunk/main/framework/source/fwe/helper/titlehelper.cxx Tue Apr 29 19:05:05 2014
@@ -596,7 +596,7 @@ void TitleHelper::impl_appendModuleName 
         const ::rtl::OUString                 sUIName = lProps.getUnpackedValueOrDefault (OFFICEFACTORY_PROPNAME_UINAME, ::rtl::OUString());
     
         // An UIname property is an optional value !
-        // So please add it to the title in case it does realy exists only.
+        // So please add it to the title in case it does really exists only.
         if (sUIName.getLength() > 0)
         {
             sTitle.appendAscii (" "    );

Modified: openoffice/trunk/main/framework/source/fwe/helper/undomanagerhelper.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/source/fwe/helper/undomanagerhelper.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/source/fwe/helper/undomanagerhelper.cxx (original)
+++ openoffice/trunk/main/framework/source/fwe/helper/undomanagerhelper.cxx Tue Apr 29 19:05:05 2014
@@ -187,7 +187,7 @@ namespace framework
         void cancel( const Reference< XInterface >& i_context )
         {
             m_caughtException <<= RuntimeException(
-                ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "Concurrency error: an ealier operation on the stack failed." ) ),
+                ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "Concurrency error: an earlier operation on the stack failed." ) ),
                 i_context
             );
             m_finishCondition.set();

Modified: openoffice/trunk/main/framework/source/fwe/xml/eventsdocumenthandler.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/source/fwe/xml/eventsdocumenthandler.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/source/fwe/xml/eventsdocumenthandler.cxx (original)
+++ openoffice/trunk/main/framework/source/fwe/xml/eventsdocumenthandler.cxx Tue Apr 29 19:05:05 2014
@@ -192,7 +192,7 @@ throw(	SAXException, RuntimeException )
 				if ( m_bEventsStartFound )
 				{
 					::rtl::OUString aErrorMessage = getErrorLineString();
-					aErrorMessage += ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "Element 'event:events' cannot be embeded into 'event:events'!" ));
+					aErrorMessage += ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "Element 'event:events' cannot be embedded into 'event:events'!" ));
 					throw SAXException( aErrorMessage, Reference< XInterface >(), Any() );
 				}
 
@@ -205,7 +205,7 @@ throw(	SAXException, RuntimeException )
 				if ( !m_bEventsStartFound )
 				{
 					::rtl::OUString aErrorMessage = getErrorLineString();
-					aErrorMessage += ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "Element 'event:event' must be embeded into element 'event:events'!" ));
+					aErrorMessage += ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "Element 'event:event' must be embedded into element 'event:events'!" ));
 					throw SAXException( aErrorMessage, Reference< XInterface >(), Any() );
 				}
 

Modified: openoffice/trunk/main/framework/source/fwe/xml/saxnamespacefilter.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/source/fwe/xml/saxnamespacefilter.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/source/fwe/xml/saxnamespacefilter.cxx (original)
+++ openoffice/trunk/main/framework/source/fwe/xml/saxnamespacefilter.cxx Tue Apr 29 19:05:05 2014
@@ -98,7 +98,7 @@ void SAL_CALL SaxNamespaceFilter::startE
 
 	try
 	{
-		// apply namespaces to all remaing attributes
+		// apply namespaces to all remaining attributes
 		for ( ::std::vector< sal_Int16 >::const_iterator i(
                   aAttributeIndexes.begin());
               i != aAttributeIndexes.end(); ++i )

Modified: openoffice/trunk/main/framework/source/fwe/xml/statusbardocumenthandler.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/source/fwe/xml/statusbardocumenthandler.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/source/fwe/xml/statusbardocumenthandler.cxx (original)
+++ openoffice/trunk/main/framework/source/fwe/xml/statusbardocumenthandler.cxx Tue Apr 29 19:05:05 2014
@@ -242,7 +242,7 @@ throw(	SAXException, RuntimeException )
 				if ( m_bStatusBarStartFound )
 				{
 					::rtl::OUString aErrorMessage = getErrorLineString();
-					aErrorMessage += ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "Element 'statusbar:statusbar' cannot be embeded into 'statusbar:statusbar'!" ));
+					aErrorMessage += ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "Element 'statusbar:statusbar' cannot be embedded into 'statusbar:statusbar'!" ));
 					throw SAXException( aErrorMessage, Reference< XInterface >(), Any() );
 				}
 
@@ -255,7 +255,7 @@ throw(	SAXException, RuntimeException )
 				if ( !m_bStatusBarStartFound )
 				{
 					::rtl::OUString aErrorMessage = getErrorLineString();
-					aErrorMessage += ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "Element 'statusbar:statusbaritem' must be embeded into element 'statusbar:statusbar'!" ));
+					aErrorMessage += ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "Element 'statusbar:statusbaritem' must be embedded into element 'statusbar:statusbar'!" ));
 					throw SAXException( aErrorMessage, Reference< XInterface >(), Any() );
 				}
 

Modified: openoffice/trunk/main/framework/source/fwe/xml/toolboxdocumenthandler.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/source/fwe/xml/toolboxdocumenthandler.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/source/fwe/xml/toolboxdocumenthandler.cxx (original)
+++ openoffice/trunk/main/framework/source/fwe/xml/toolboxdocumenthandler.cxx Tue Apr 29 19:05:05 2014
@@ -251,7 +251,7 @@ throw(	SAXException, RuntimeException )
 				if ( m_bToolBarStartFound )
 				{
 				    ::rtl::OUString aErrorMessage = getErrorLineString();
-				    aErrorMessage += ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "Element 'toolbar:toolbar' cannot be embeded into 'toolbar:toolbar'!" ));
+				    aErrorMessage += ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "Element 'toolbar:toolbar' cannot be embedded into 'toolbar:toolbar'!" ));
 				    throw SAXException( aErrorMessage, Reference< XInterface >(), Any() );
 				}
                         else
@@ -300,7 +300,7 @@ throw(	SAXException, RuntimeException )
 				if ( !m_bToolBarStartFound )
 				{
 					::rtl::OUString aErrorMessage = getErrorLineString();
-					aErrorMessage += ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "Element 'toolbar:toolbaritem' must be embeded into element 'toolbar:toolbar'!" ));
+					aErrorMessage += ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "Element 'toolbar:toolbaritem' must be embedded into element 'toolbar:toolbar'!" ));
 					throw SAXException( aErrorMessage, Reference< XInterface >(), Any() );
 				}
 
@@ -401,7 +401,7 @@ throw(	SAXException, RuntimeException )
 
 							case TB_ATTRIBUTE_STYLE:
 							{
-								// read space seperated item style list
+								// read space separated item style list
 								::rtl::OUString aTemp = xAttribs->getValueByIndex( n );
 								sal_Int32 nIndex = 0;
 

Modified: openoffice/trunk/main/framework/source/fwi/classes/protocolhandlercache.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/source/fwi/classes/protocolhandlercache.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/source/fwi/classes/protocolhandlercache.cxx (original)
+++ openoffice/trunk/main/framework/source/fwi/classes/protocolhandlercache.cxx Tue Apr 29 19:05:05 2014
@@ -99,7 +99,7 @@ PatternHash::iterator PatternHash::findP
 /**
     @short      initialize static member of class HandlerCache
     @descr      We use a singleton pattern to implement this handler cache.
-                That means it use two static member list to hold all neccessary informations
+                That means it use two static member list to hold all necessary informations
                 and a ref count mechanism to create/destroy it on demand.
 
     @modified   30.04.2002 11:13, as96863
@@ -113,7 +113,7 @@ HandlerCFGAccess* HandlerCache::m_pConfi
 
 /**
     @short      ctor of the cache of all registered protoco handler
-    @descr      It tries to open the right configuration package automaticly
+    @descr      It tries to open the right configuration package automatically
                 and fill the internal structures. After that the cache can be
                 used for read access on this data and perform some search
                 operations on it.
@@ -198,7 +198,7 @@ sal_Bool HandlerCache::search( const ::r
 
 /**
     @short      search for a registered handler by using an URL struct
-    @descr      We combine neccessary parts of this struct to a valid URL string
+    @descr      We combine necessary parts of this struct to a valid URL string
                 and call our other search method ...
                 It's a helper for outside code.
 
@@ -247,7 +247,7 @@ void HandlerCache::takeOver(HandlerHash*
 
 /**
     @short      dtor of the config access class
-    @descr      It opens the configuration package automaticly by using base class mechanism.
+    @descr      It opens the configuration package automatically by using base class mechanism.
                 After that "read()" method of this class should be called to use it.
 
     @param      sPackage

Modified: openoffice/trunk/main/framework/source/fwi/jobs/configaccess.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/source/fwi/jobs/configaccess.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/source/fwi/jobs/configaccess.cxx (original)
+++ openoffice/trunk/main/framework/source/fwi/jobs/configaccess.cxx Tue Apr 29 19:05:05 2014
@@ -214,7 +214,7 @@ void ConfigAccess::close()
     @descr  It's not allowed to safe this c++ (!) reference outside. You have
             to use it directly. Further you must use our public lock member m_aLock
             to synchronize your code with our internal structures and our interface
-            methods. Acquire it before you call cfg() and release it afterwards immediatly.
+            methods. Acquire it before you call cfg() and release it afterwards immediately.
 
             E.g.:   ConfigAccess aAccess(...);
                     ReadGuard aReadLock(aAccess.m_aLock);

Modified: openoffice/trunk/main/framework/source/fwi/threadhelp/lockhelper.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/source/fwi/threadhelp/lockhelper.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/source/fwi/threadhelp/lockhelper.cxx (original)
+++ openoffice/trunk/main/framework/source/fwi/threadhelp/lockhelper.cxx Tue Apr 29 19:05:05 2014
@@ -163,7 +163,7 @@ LockHelper::~LockHelper()
                 we must simulate it as a write access!
 
     @attention  If a shareable osl mutex exist, he must be used as twice!
-                It's neccessary for some cppu-helper classes ...
+                It's necessary for some cppu-helper classes ...
 
     @seealso    method acquireWriteAccess()
 
@@ -200,7 +200,7 @@ void LockHelper::acquire()
                 we must simulate it as a write access!
 
     @attention  If a shareable osl mutex exist, he must be used as twice!
-                It's neccessary for some cppu-helper classes ...
+                It's necessary for some cppu-helper classes ...
 
     @seealso    method releaseWriteAccess()
 
@@ -237,7 +237,7 @@ void LockHelper::release()
                 We use m_eLockType to differ between all possible "lock-member"!!!
 
     @attention  If a shareable osl mutex exist, he must be used as twice!
-                It's neccessary for some cppu-helper classes ...
+                It's necessary for some cppu-helper classes ...
 
     @seealso    method releaseReadAccess()
 
@@ -273,7 +273,7 @@ void LockHelper::acquireReadAccess()
                 We use m_eLockType to differ between all possible "lock-member"!!!
 
     @attention  If a shareable osl mutex exist, he must be used as twice!
-                It's neccessary for some cppu-helper classes ...
+                It's necessary for some cppu-helper classes ...
 
     @seealso    method acquireReadAccess()
 
@@ -311,7 +311,7 @@ void LockHelper::releaseReadAccess()
                 We use m_eLockType to differ between all possible "lock-member"!!!
 
     @attention  If a shareable osl mutex exist, he must be used as twice!
-                It's neccessary for some cppu-helper classes ...
+                It's necessary for some cppu-helper classes ...
 
     @seealso    method releaseWriteAccess()
 
@@ -347,7 +347,7 @@ void LockHelper::acquireWriteAccess()
                 We use m_eLockType to differ between all possible "lock-member"!!!
 
     @attention  If a shareable osl mutex exist, he must be used as twice!
-                It's neccessary for some cppu-helper classes ...
+                It's necessary for some cppu-helper classes ...
 
     @seealso    method acquireWriteAccess()
 
@@ -388,10 +388,10 @@ void LockHelper::releaseWriteAccess()
 
     @attention  a) Don't call this method if you are not a writer!
                     Results are not defined then ...
-                    An upgrade can't be implemented realy ... because acquiring new access
+                    An upgrade can't be implemented really ... because acquiring new access
                     will be the same - there no differences!
                 b) Without function if m_eLockTyp is different from E_FAIRRWLOCK(!) ...
-                    because, a mutex don't support it realy.
+                    because, a mutex don't support it really.
 
     @seealso    -
 

Modified: openoffice/trunk/main/framework/source/fwi/threadhelp/transactionmanager.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/source/fwi/threadhelp/transactionmanager.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/source/fwi/uielement/constitemcontainer.cxx (original)
+++ openoffice/trunk/main/framework/source/fwi/uielement/constitemcontainer.cxx Tue Apr 29 19:05:05 2014
@@ -434,7 +434,7 @@ throw (::com::sun::star::beans::UnknownP
         if( pInfoHelper == NULL )
 		{
 			// Define static member to give structure of properties to baseclass "OPropertySetHelper".
-			// "impl_getStaticPropertyDescriptor" is a non exported and static funtion, who will define a static propertytable.
+			// "impl_getStaticPropertyDescriptor" is a non exported and static function, who will define a static propertytable.
 			// "sal_True" say: Table is sorted by name.
             static ::cppu::OPropertyArrayHelper aInfoHelper( impl_getStaticPropertyDescriptor(), sal_True );
 			pInfoHelper = &aInfoHelper;

Modified: openoffice/trunk/main/framework/source/fwi/uielement/rootitemcontainer.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/source/fwi/uielement/rootitemcontainer.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/source/fwi/uielement/rootitemcontainer.cxx (original)
+++ openoffice/trunk/main/framework/source/fwi/uielement/rootitemcontainer.cxx Tue Apr 29 19:05:05 2014
@@ -402,7 +402,7 @@ void SAL_CALL RootItemContainer::getFast
         if( pInfoHelper == NULL )
 		{
 			// Define static member to give structure of properties to baseclass "OPropertySetHelper".
-			// "impl_getStaticPropertyDescriptor" is a non exported and static funtion, who will define a static propertytable.
+			// "impl_getStaticPropertyDescriptor" is a non exported and static function, who will define a static propertytable.
 			// "sal_True" say: Table is sorted by name.
             static ::cppu::OPropertyArrayHelper aInfoHelper( impl_getStaticPropertyDescriptor(), sal_True );
 			pInfoHelper = &aInfoHelper;

Modified: openoffice/trunk/main/framework/source/helper/ocomponentaccess.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/source/helper/ocomponentaccess.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/source/helper/ocomponentaccess.cxx (original)
+++ openoffice/trunk/main/framework/source/helper/ocomponentaccess.cxx Tue Apr 29 19:05:05 2014
@@ -230,7 +230,7 @@ css::uno::Reference< XComponent > OCompo
 
 	ATTENTION
 
-		If you miss a test for one of this parameters, contact the autor or add it himself !(?)
+		If you miss a test for one of this parameters, contact the author or add it himself !(?)
 		But ... look for right testing! See using of this methods!
 -----------------------------------------------------------------------------------------------------------------*/
 

Modified: openoffice/trunk/main/framework/source/helper/ocomponentenumeration.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/source/helper/ocomponentenumeration.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/source/helper/ocomponentenumeration.cxx (original)
+++ openoffice/trunk/main/framework/source/helper/ocomponentenumeration.cxx Tue Apr 29 19:05:05 2014
@@ -188,7 +188,7 @@ void OComponentEnumeration::impl_resetOb
 
 	ATTENTION
 
-		If you miss a test for one of this parameters, contact the autor or add it himself !(?)
+		If you miss a test for one of this parameters, contact the author or add it himself !(?)
 		But ... look for right testing! See using of this methods!
 -----------------------------------------------------------------------------------------------------------------*/
 

Modified: openoffice/trunk/main/framework/source/helper/oframes.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/source/helper/oframes.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/source/helper/oframes.cxx (original)
+++ openoffice/trunk/main/framework/source/helper/oframes.cxx Tue Apr 29 19:05:05 2014
@@ -420,7 +420,7 @@ void OFrames::impl_appendSequence(			Seq
 
 	ATTENTION
 
-		If you miss a test for one of this parameters, contact the autor or add it himself !(?)
+		If you miss a test for one of this parameters, contact the author or add it himself !(?)
 		But ... look for right testing! See using of this methods!
 -----------------------------------------------------------------------------------------------------------------*/
 

Modified: openoffice/trunk/main/framework/source/helper/persistentwindowstate.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/source/helper/persistentwindowstate.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/source/helper/persistentwindowstate.cxx (original)
+++ openoffice/trunk/main/framework/source/helper/persistentwindowstate.cxx Tue Apr 29 19:05:05 2014
@@ -288,7 +288,7 @@ void PersistentWindowState::implst_setWi
         ::vos::OClearableGuard aSolarLock(Application::GetSolarMutex());
         
         Window* pWindow = VCLUnoHelper::GetWindow(xWindow);
-        // check for system window is neccessary to guarantee correct pointer cast!
+        // check for system window is necessary to guarantee correct pointer cast!
         if (
             (pWindow                  ) &&
             (pWindow->IsSystemWindow())
@@ -326,7 +326,7 @@ void PersistentWindowState::implst_setWi
     if (!pWindow)
         return;
     
-    // check for system and work window - its neccessary to guarantee correct pointer cast!
+    // check for system and work window - its necessary to guarantee correct pointer cast!
     sal_Bool bSystemWindow = pWindow->IsSystemWindow(); 
     sal_Bool bWorkWindow   = (pWindow->GetType() == WINDOW_WORKWINDOW);
--- openoffice/trunk/main/framework/source/application/login.cxx (original)
+++ openoffice/trunk/main/framework/source/application/login.cxx Tue Apr 29 19:05:05 2014
@@ -63,8 +63,8 @@
 //_________________________________________________________________________________________________________________
 
 #define	TEMPFILE_ENCODING			RTL_TEXTENCODING_UTF8			// encoding of written temp. ascii file
-#define	LOGIN_RDB					DECLARE_ASCII("login.rdb")		// name of our own registry file - neccessary to create own servicemanager
-#define SEPERATOR                   "\n"                            // used to seperate parts in temp. file
+#define	LOGIN_RDB					DECLARE_ASCII("login.rdb")		// name of our own registry file - necessary to create own servicemanager
+#define SEPERATOR                   "\n"                            // used to separate parts in temp. file
 
 #define MINARGUMENTCOUNT            1                               // count of min. required arguments
 #define ARGUMENTFOUND               0                               // OUString::compareTo returns 0 if searched string match given one
@@ -99,7 +99,7 @@ using namespace ::com::sun::star::beans	
 	@descr		We need this temp. file to share informations between our dialog and different processes, which
 				can't use vcl directly. Caller of this executable give us the file name as an argument - we save
 				all informations in it - caller can read it and MUST delete temp. file.
-				This is neccessary for example; to hide the password!
+				This is necessary for example; to hide the password!
 
 	@implements	-
 
@@ -149,7 +149,7 @@ void LoginApplication::Main()
 	impl_parseCommandline();
 	LOG_ASSERT( !(m_sTempFile.getLength()<1), "LoginApplication::Main()\nWrong or missing argument for temp. file detected!\n" )
 
 	// Try to get neccessary dialog service.
 	// By the way - cast it to interface XPropertySet too - we need it later.
 	// (define SERVICENAME... comes from defines.hxx!)
 	Reference< XDialog >		xLoginDialog( xServiceManager->createInstance( SERVICENAME_LOGINDIALOG ), UNO_QUERY );
@@ -200,7 +200,7 @@ void LoginApplication::Main()
 		}
 
 		// Build string for output.
-		// At this point it doesnt matter if information exist or not!
+		// At this point it doesn't matter if information exist or not!
         // Format of output: "<decision>    [0|1]       SEPERATOR
         //                    <username>    [string]    SEPERATOR
         //                    <password>    [string]    SEPERATOR
@@ -229,8 +229,8 @@ void LoginApplication::Main()
         sBuffer.appendAscii ( SEPERATOR         );
 
 		// Write informations in temp. file.
-		// If given file name isnt valid ... caller will have a problem!!!
-		// If fil already exist (That's out of specification!!!) we overwrite it everytime.
+		// If given file name isn't valid ... caller will have a problem!!!
+		// If fil already exist (That's out of specification!!!) we overwrite it every time.
 		FILE* pFile = fopen( m_sTempFile.getStr(), "w" );
 		LOG_ASSERT( !(pFile==NULL), "LoginApplication::Main()\nCould not open file!\n" );
 		if( pFile != NULL )
@@ -257,7 +257,7 @@ void LoginApplication::impl_parseCommand
 	OUString	sArgument									;
     OUString    sValue                                      ;
 
-	// Warn programmer if argument count isnt ok!
+	// Warn programmer if argument count isn't ok!
     LOG_ASSERT( !(nCount!=MINARGUMENTCOUNT), "LoginApplication::impl_parseCommandline()\nWrong argument count detected!\n" )
 
     // Reset all possible argument variables to defaults if someone is missing.
@@ -149,7 +149,7 @@ void LoginApplication::Main()
 	LOG_ASSERT( !(m_sTempFile.getLength()<1), "LoginApplication::Main()\nWrong or missing argument for temp. file detected!\n" )
 
-	// Try to get neccessary dialog service.
+	// Try to get necessary dialog service.
 	// By the way - cast it to interface XPropertySet too - we need it later.
 	// (define SERVICENAME... comes from defines.hxx!)

Modified: openoffice/trunk/main/framework/source/classes/framecontainer.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/source/classes/framecontainer.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/source/classes/framecontainer.cxx (original)
+++ openoffice/trunk/main/framework/source/classes/framecontainer.cxx Tue Apr 29 19:05:05 2014
@@ -73,12 +73,12 @@ namespace framework{
     @short      initialize an empty container
     @descr      The container will be empty then - special features (e.g. the async quit mechanism) are disabled.
 
-    @threadsafe not neccessary - its not a singleton
+    @threadsafe not necessary - its not a singleton
     @modified   01.07.2002 14:42,as96863
  *****************************************************************************************************************/
 FrameContainer::FrameContainer()
         // initialize base classes first.
         // Order is neccessary for right initilization of his and OUR member ... m_aLock
         : ThreadHelpBase ( &Application::GetSolarMutex()                  )
 /*DEPRECATEME
         , m_bAsyncQuit   ( sal_False                                      ) // default must be "disabled"!
@@ -91,7 +91,7 @@ FrameContainer::FrameContainer()
     @short      deinitialize may a filled container
     @descr      Special features (if the currently are running) will be dsiabled and we free all used other ressources.
 
-    @threadsafe not neccessary - its not a singleton
+    @threadsafe not necessary - its not a singleton
     @modified   01.07.2002 14:43,as96863
  *****************************************************************************************************************/
 FrameContainer::~FrameContainer()
@@ -139,7 +139,7 @@ void FrameContainer::append( const css::
 void FrameContainer::remove( const css::uno::Reference< css::frame::XFrame >& xFrame )
 {
     /* SAFE { */
     // write lock neccessary for follwing erase()!
     WriteGuard aWriteLock( m_aLock );
 
     TFrameIterator aSearchedItem = ::std::find( m_aContainer.begin(), m_aContainer.end(), xFrame );
@@ -244,7 +244,7 @@ sal_uInt32 FrameContainer::getCount() co
                 So it will be marked as deprecated and should be replaced by "getAllElements()".
 
     @param      nIndex
-                    a valud between 0 and (getCount()-1) to adress one container item
+                    a valud between 0 and (getCount()-1) to address one container item
 
     @return     a reference to a frame inside the container, which match with given index
 
@@ -278,7 +278,7 @@ css::uno::Reference< css::frame::XFrame 
     @short      returns a snapshot of all currently existing frames inside this container
     @descr      Should be used to replace the deprecated functions getCount()/operator[]!
 
-    @return     a list of all frame refrences inside this container
+    @return     a list of all frame references inside this container
 
     @threadsafe yes
     @modified   01.07.2002 15:09,as96863
@@ -73,12 +73,12 @@ namespace framework{
 FrameContainer::FrameContainer()
         // initialize base classes first.
-        // Order is neccessary for right initilization of his and OUR member ... m_aLock
+        // Order is necessary for right initilization of his and OUR member ... m_aLock
         : ThreadHelpBase ( &Application::GetSolarMutex()                  )
 /*DEPRECATEME
@@ -139,7 +139,7 @@ void FrameContainer::append( const css::
 {
     /* SAFE { */
-    // write lock neccessary for follwing erase()!
+    // write lock necessary for follwing erase()!
     WriteGuard aWriteLock( m_aLock );
 

Modified: openoffice/trunk/main/framework/source/classes/menumanager.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/source/classes/menumanager.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/source/dispatch/dispatchprovider.cxx (original)
+++ openoffice/trunk/main/framework/source/dispatch/dispatchprovider.cxx Tue Apr 29 19:05:05 2014
@@ -100,7 +100,7 @@ DEFINE_XTYPEPROVIDER_2( DispatchProvider
 
 /**
     @short      standard ctor/dtor
-    @descr      These initialize a new instance of tihs class with needed informations for work.
+    @descr      These initialize a new instance of this class with needed informations for work.
                 We hold a weakreference to our owner frame which start dispatches at us.
                 We can't use a normal reference because he hold a reference of us too ...
                 nobody can die so ...!
@@ -388,7 +388,7 @@ css::uno::Reference< css::frame::XDispat
         {
             // Don''t use findFrame() here - because it's not possible to find
             // a top lebel frame without knowing his name. And a frame with name
             // "" can't be realy searched! That's why forward query to any parent
             // explicitly.
             css::uno::Reference< css::frame::XDispatchProvider > xProvider( xFrame->getCreator(), css::uno::UNO_QUERY );
             if (xProvider.is())
@@ -428,7 +428,7 @@ css::uno::Reference< css::frame::XDispat
     {
         css::uno::Reference< css::frame::XDispatchProvider > xParent( xFrame->getCreator(), css::uno::UNO_QUERY );
         if (xParent.is())
-            // SELF => we must adress the parent directly... and not his parent or any other parent!
+            // SELF => we must address the parent directly... and not his parent or any other parent!
             xDispatcher = xParent->queryDispatch(aURL, SPECIALTARGET_SELF, 0);
     }
 
@@ -509,7 +509,7 @@ css::uno::Reference< css::frame::XDispat
 
 		// Not for controller - not for protocol handler
 		// It should be a loadable content - may be a file. Check it ...
-		// This check is neccessary to found out, that
+		// This check is necessary to found out, that
 		// support for some protocols isn't installed by user. May be
 		// "ftp" isn't available. So we suppress creation of our self dispatcher.
 		// The result will be clear. He can't handle it - but he would try it.
@@ -606,7 +606,7 @@ css::uno::Reference< css::frame::XDispat
         }
         catch(css::uno::Exception&) {}
 
-        // look if initialization is neccessary
+        // look if initialization is necessary
         css::uno::Reference< css::lang::XInitialization > xInit( xHandler, css::uno::UNO_QUERY );
         if (xInit.is())
         {
@@ -646,7 +646,7 @@ css::uno::Reference< css::frame::XDispat
                 Thats why we implement this method. It return an already existing helper or create a new one otherwise.
 
     @attention  The parameter sTarget and nSearchFlags are defaulted to "" and 0!
-                Please use it only, if you can be shure, that the realy given by the outside calli!
+                Please use it only, if you can be sure, that the really given by the outside calli!
                 Mostly it depends from the parameter eHelper is they are required or not.
 
     @param      eHelper
@@ -388,7 +388,7 @@ css::uno::Reference< css::frame::XDispat
             // Don''t use findFrame() here - because it's not possible to find
             // a top lebel frame without knowing his name. And a frame with name
-            // "" can't be realy searched! That's why forward query to any parent
+            // "" can't be really searched! That's why forward query to any parent
             // explicitly.
             css::uno::Reference< css::frame::XDispatchProvider > xProvider( xFrame->getCreator(), css::uno::UNO_QUERY );

Modified: openoffice/trunk/main/framework/source/dispatch/helpagentdispatcher.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/source/dispatch/helpagentdispatcher.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/source/dispatch/oxt_handler.cxx (original)
+++ openoffice/trunk/main/framework/source/dispatch/oxt_handler.cxx Tue Apr 29 19:05:05 2014
@@ -175,12 +175,12 @@ Oxt_Handler::~Oxt_Handler()
 
     @short      try to load audio file
     @descr      This method try to load given audio file by URL and play it. We use vcl/Sound class to do that.
-                Playing of sound is asynchron everytime.
+                Playing of sound is asynchron every time.
 
     @attention  We must hold us alive by ourself ... because we use async. vcl sound player ... but playing is started
                 in async interface call "dispatch()" too. And caller forget us imediatly. But then our uno ref count
                 will decreased to 0 and will die. The only solution is to use own reference to our implementation.
-                But we do it for realy started jobs only and release it during call back of vcl.
+                But we do it for really started jobs only and release it during call back of vcl.
 
     @seealso    class vcl/Sound
     @seealso    method implts_PlayerNotify()
@@ -250,7 +250,7 @@ void SAL_CALL Oxt_Handler::dispatch( con
 
     @attention  a) We don't need any mutex here ... because we don't use any member!
                 b) Dont' use internal player instance "m_pPlayer" to detect given sound file!
-                   It's not neccessary to do that ... and we can use temp. variable to do the same.
+                   It's not necessary to do that ... and we can use temp. variable to do the same.
                    This way is easy - we don't must synchronize it with currently played sounds!
                    Another reason to do so ... We are a listener on our internal ma_Player object.
                    If you would call "IsSoundFile()" on this instance, he would call us back and
@@ -267,7 +267,7 @@ void SAL_CALL Oxt_Handler::dispatch( con
 ::rtl::OUString SAL_CALL Oxt_Handler::detect( css::uno::Sequence< css::beans::PropertyValue >& lDescriptor )
     throw( css::uno::RuntimeException )
 {
     // Our default is "nothing". So we can return it, if detection failed or fily type is realy unknown.
     ::rtl::OUString sTypeName;
 
     // Analyze given descriptor to find filename or input stream or ...
@@ -267,7 +267,7 @@ void SAL_CALL Oxt_Handler::dispatch( con
     throw( css::uno::RuntimeException )
 {
-    // Our default is "nothing". So we can return it, if detection failed or fily type is realy unknown.
+    // Our default is "nothing". So we can return it, if detection failed or fily type is really unknown.
     ::rtl::OUString sTypeName;
 

Modified: openoffice/trunk/main/framework/source/dispatch/servicehandler.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/source/dispatch/servicehandler.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/source/fwi/threadhelp/transactionmanager.cxx (original)
+++ openoffice/trunk/main/framework/source/fwi/threadhelp/transactionmanager.cxx Tue Apr 29 19:05:05 2014
@@ -102,7 +102,7 @@ TransactionManager::~TransactionManager(
     @short      set new working mode
     @descr      These implementation knows for states of working: E_INIT, E_WORK, E_CLOSING, E_CLOSE
                 You can step during this ones only from the left to the right side and start at left side again!
-                (This is neccessary e.g. for refcounted objects!)
+                (This is necessary e.g. for refcounted objects!)
                 This call will block till all current existing transactions was finished.
                 Follow results occure:
                     E_INIT        :  All requests on this implementation are refused.
@@ -146,7 +146,7 @@ void  TransactionManager::setWorkingMode
     }
 
     // Wait for current existing transactions then!
     // (Only neccessary for changing to E_BEFORECLOSE or E_CLOSE! ...
     // otherwise; if you wait at setting E_WORK another thrad could finish a acquire-call during our unlock() and wait() call
     // ... and we will wait forever here!!!)
     // Don't forget to release access mutex before.
@@ -213,7 +213,7 @@ EWorkingMode TransactionManager::getWork
 
     @seealso    method unregisterTransaction()
 
-    @param      "eMode"     ,used to enable/disable throwing exceptions automaticly for rejected calls
+    @param      "eMode"     ,used to enable/disable throwing exceptions automatically for rejected calls
     @param      "eReason"   ,reason for rejected calls if eMode=E_NOEXCEPTIONS
     @return     -
 
@@ -317,7 +317,7 @@ sal_Bool  TransactionManager::isCallReje
 
 /*-****************************************************************************************************//**
     @short      throw any exceptions for rejected calls
-    @descr      If user whish to use our automaticly exception mode we use this impl-method.
+    @descr      If user whish to use our automatically exception mode we use this impl-method.
                 We check all combinations of eReason and eExceptionMode and throw right exception with some
                 descriptions for recipient of it.
 
@@ -146,7 +146,7 @@ void  TransactionManager::setWorkingMode
 
     // Wait for current existing transactions then!
-    // (Only neccessary for changing to E_BEFORECLOSE or E_CLOSE! ...
+    // (Only necessary for changing to E_BEFORECLOSE or E_CLOSE! ...
     // otherwise; if you wait at setting E_WORK another thrad could finish a acquire-call during our unlock() and wait() call
     // ... and we will wait forever here!!!)

Modified: openoffice/trunk/main/framework/source/fwi/uielement/constitemcontainer.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/source/fwi/uielement/constitemcontainer.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================